@@ -3,16 +3,16 @@
 # Copyright 2006-2008 Sun Microsystems Inc.
 #
 # This library is free software; you can redistribute it and/or
-# modify it under the terms of the GNU Library General Public
+# modify it under the terms of the GNU Lesser General Public
 # License as published by the Free Software Foundation; either
-# version 2 of the License, or (at your option) any later version.
+# version 2.1 of the License, or (at your option) any later version.
 #
 # This library is distributed in the hope that it will be useful,
 # but WITHOUT ANY WARRANTY; without even the implied warranty of
 # MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-# Library General Public License for more details.
+# Lesser General Public License for more details.
 #
-# You should have received a copy of the GNU Library General Public
+# You should have received a copy of the GNU Lesser General Public
 # License along with this library; if not, write to the
 # Free Software Foundation, Inc., Franklin Street, Fifth Floor,
 # Boston MA  02110-1301 USA.
@@ -176,13 +176,16 @@ class BrlMon(gtk.Window):
                 self.cellFrames[i].set_shadow_type(
                     gtk.SHADOW_OUT)
 
-            if mask:
-                if (mask[i] == DOTS_78):
-                    markup += ATTRIBUTE_78
-                elif (mask[i] == DOT_7):
-                    markup += ATTRIBUTE_7
-                elif (mask[i] == DOT_8):
-                    markup += ATTRIBUTE_8
+            try:
+                if mask:
+                    if (mask[i] == DOTS_78):
+                        markup += ATTRIBUTE_78
+                    elif (mask[i] == DOT_7):
+                        markup += ATTRIBUTE_7
+                    elif (mask[i] == DOT_8):
+                        markup += ATTRIBUTE_8
+            except:
+                pass
 
             self.cellLabels[i].set_markup(
                 "<span" + markup + ">%s</span>" % char)
